==> refcodes-filesystem-1.1.3-sources.jar: org/refcodes/filesystem/FileSystemAccessException.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/LICENSE-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.filesystem;

public class FileSystemAccessException extends FileSystemRuntimeException {

	private static final long serialVersionUID = 1L;

	public FileSystemAccessException( String aMessage, String aErrorCode ) {
		super( aMessage, aErrorCode );
	}

	public FileSystemAccessException( String aMessage, Throwable aCause, String aErrorCode ) {
		super( aMessage, aCause, aErrorCode );
	}

	public FileSystemAccessException( String message, Throwable cause ) {
		super( message, cause );
	}

	public FileSystemAccessException( String message ) {
		super( message );
	}

	public FileSystemAccessException( Throwable aCause, String aErrorCode ) {
		super( aCause, aErrorCode );
	}

	public FileSystemAccessException( Throwable cause ) {
		super( cause );
	}
}

==> refcodes-filesystem-1.10.0-sources.jar: org/refcodes/filesystem/FileSystemAccessException.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/LICENSE-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.filesystem;

/**
 * The Class FileSystemAccessException.
 */
public class FileSystemAccessException extends FileSystemRuntimeException {

	private static final long serialVersionUID = 1L;

	/**
	 * Instantiates a new file system access exception.
	 *
	 * @param aMessage the message
	 * @param aErrorCode the error code
	 */
	public FileSystemAccessException( String aMessage, String aErrorCode ) {
		super( aMessage, aErrorCode );
	}

	/**
	 * Instantiates a new file system access exception.
	 *
	 * @param aMessage the message
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public FileSystemAccessException( String aMessage, Throwable aCause, String aErrorCode ) {
		super( aMessage, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new file system access exception.
	 *
	 * @param message the message
	 * @param cause the cause
	 */
	public FileSystemAccessException( String message, Throwable cause ) {
		super( message, cause );
	}

	/**
	 * Instantiates a new file system access exception.
	 *
	 * @param message the message
	 */
	public FileSystemAccessException( String message ) {
		super( message );
	}

	/**
	 * Instantiates a new file system access exception.
	 *
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public FileSystemAccessException( Throwable aCause, String aErrorCode ) {
		super( aCause, aErrorCode );
	}

	/**
	 * Instantiates a new file system access exception.
	 *
	 * @param cause the cause
	 */
	public FileSystemAccessException( Throwable cause ) {
		super( cause );
	}
}
